# Best Practices for the Integration API
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/best-practices-for-integration-api#overview)
  * [Use the UI](https://help.sap.com/docs/leanix/ea/best-practices-for-integration-api#use-the-ui)
  * [Check Scope Before Firing Test Runs](https://help.sap.com/docs/leanix/ea/best-practices-for-integration-api#check-scope-before-firing-test-runs)
  * [Adhere to Proper Processor Versioning Convention](https://help.sap.com/docs/leanix/ea/best-practices-for-integration-api#adhere-to-proper-processor-versioning-convention)
  * [Use Webhooks](https://help.sap.com/docs/leanix/ea/best-practices-for-integration-api#use-webhooks)
  * [Leverage Deletion Scope](https://help.sap.com/docs/leanix/ea/best-practices-for-integration-api#leverage-deletion-scope)
  * [Cover All Edge Cases to Eliminate Warnings and Errors](https://help.sap.com/docs/leanix/ea/best-practices-for-integration-api#cover-all-edge-cases-to-eliminate-warnings-and-errors)
  * [Configuring Automated Nightly Runs](https://help.sap.com/docs/leanix/ea/best-practices-for-integration-api#configuring-automated-nightly-runs)


Best practices and tips to optimize your usage of the Integration API.
